[![Github Actions Shield](https://img.shields.io/github/workflow/status/sdv-dev/DeepEcho/Run%20Tests)](https://github.com/sdv-dev/DeepEcho/actions)
[![Coverage Status](https://codecov.io/gh/sdv-dev/DeepEcho/branch/master/graph/badge.svg)](https://codecov.io/gh/sdv-dev/DeepEcho)

<br/>

# Overview
The **DeepEcho** library implements methods for modeling mixed-type 
multivariate time series. It provides multiple models and benchmarks to enable 
rapid research and development.


# Installation
To install the ``DeepEcho`` library from source, run the following:

```bash
git clone https://github.com/sdv-dev/DeepEcho
cd DeepEcho
make install-develop
```
